# ophyd-basler

[![Tests](https://github.com/BNL-ATF/ophyd-basler/actions/workflows/testing.yml/badge.svg)](https://github.com/BNL-ATF/ophyd-basler/actions/workflows/testing.yml)
[![PyPI](https://img.shields.io/pypi/v/ophyd-basler.svg?logo=pypi&logoColor=white&label=PyPI)](https://pypi.python.org/pypi/ophyd-basler)

Basler camera API integration with ophyd

* Free software: BSD-3-Clause license
